------------------------------------------
---  Copyright HDRsoft - www.hdrsoft.com   
------------------------------------------

local LrApplication = import 'LrApplication'
local LrBinding = import 'LrBinding'
local LrView = import 'LrView'
local LrDialogs = import 'LrDialogs'
local LrFunctionContext = import 'LrFunctionContext'
local LrPathUtils = import 'LrPathUtils'
local LrErrors = import 'LrErrors'
local LrHttp = import "LrHttp"
local LrTasks = import 'LrTasks'
local prefs = import 'LrPrefs'.prefsForPlugin() 
local LrLogger = import 'LrLogger'

local myLogger = LrLogger('PhotomatixLogger')
myLogger:enable("print") 

require 'CreateHdrUtils'



function regSectionLicensed( f, props ) 


	local regText=LOC "$$$/Photomatix/Registration/RegistrationInfo=Your copy of the plugin is registered with license key:" 

	return {

	{
     title = LOC "$$$/Photomatix/Registration/RegistrationSectionTitle=Plug-in Registration",
                        
     f:static_text {
		fill_horizontal = 1,
        height_in_lines = 2,
        --- font = "<system/small/bold>",
        width = 300,
        title = string.format('%s %s',regText, prefs.licenseKey),
	},
	},
	
	}
end


function regSectionTrial( f, props ) 

	props.licenseKey="bidon"

	return {

	{
     title = "Plugin Registration",
                        
	f:static_text {
		fill_horizontal = 1,
        height_in_lines = 3,
        width = 300,
        title = LOC "$$$/Photomatix/Registration/RegistrationText1=Your copy of the plugin is in trial mode, which means that a watermark will be added to the 32-bit HDR file created.  You can register your copy and avoid the watermark by purchasing a license key from the www.hdrsoft.com website.",
	},
	
	
	f:push_button {
		width = 150, 
		title = LOC "$$$/Photomatix/Registration/PurchaseButton=Purchase License Key", 
		enabled = true, 
		action = function()
			LrHttp.openUrlInBrowser(LOC "$$$/Photomatix/Registration/PurchaseURL=http://www.hdrsoft.com/order.php") 
		end,
	},

     f:static_text {
		fill_horizontal = 1,
        height_in_lines = 2,
        width = 300,
        title = LOC "$$$/Photomatix/Registration/RegistrationText2=To register your copy, please copy/paste your license key in the field below, then click on the 'Register' button",
	},
	
	
	f:row {
		spacing = f:control_spacing(),
	
		f:static_text {
			title =LOC "$$$/Photomatix/Registration/LicenseKeyLabel=License Key:",
			height_in_lines = 2,
		},
	
		f:edit_field	{
			place_horizontal=0.20,
			width_in_chars = 24,
			value = LrView.bind 'licenseKey', 
			immediate = true,
		},
		f:push_button {
			place_horizontal=0.72,
			width = 80, 
			title = LOC "$$$/Photomatix/Registration/RegisterButton=Register", 
			enabled = true, 
			action = function()
			
			LrTasks.startAsyncTask( function()
				local validated=CreateHdrUtils.Validate(props.licenseKey)

				if validated then
					LrDialogs.message( LOC "$$$/Photomatix/Registration/RegistrationOK=Registration successful. Thank you!")
				else
					LrDialogs.message( LOC "$$$/Photomatix/Registration/RegistrationFailed=The license key you entered could not be validated.")						
				end	
			end)
			end,
		},

	},
	
	
	
	},
	
	}
end





--------------- main function
return {

	sectionsForBottomOfDialog = function( f, props ) 

		if (prefs.isRegistered==nil) then
			return
		end

		if ((prefs.isRegistered) and (prefs.licenseKey~=nil)) then 
			return regSectionLicensed( f, props )
		--else	
		--	return regSectionTrial( f, props )
		end
	
	end     

}



